@@ -74,16 +74,17 @@ VALIDATION_ERROR_CERTIFICATE_VALIDATION_TYPE  = 'DV Certificates are favored by
 VALIDATION_ERROR_DNSSEC_REGISTERED_DOMAIN = 'DNSSEC (rfc6840) provided DS and DNSKEY records, but validation failed for the target subdomain and registered domain name'
 VALIDATION_ERROR_DNSSEC_TARGET = 'DNSSEC (rfc6840) provided DS and DNSKEY records, but validation failed for the target subdomain and only the registered domain name could be validated'
 VALIDATION_ERROR_DNSSEC_MISSING = 'This domain is not enabled for DNSSEC (rfc6840), DS and DNSKEY records were not provided'
-VALIDATION_ERROR_SESSION_RESUMPTION_CACHING = 'This server has confidentiality vulnerability and a tracking issue affecting privacy; rfc5246 recommends a lifetime of session IDs of less than 24 hours where afterwards the client attempts a resumption and only then the server falls back to a full handshake. The server can link both PSKs to the same user, session resumption caching allows a user identity to be shared with third-party trackers observing traffic on this server. Prior to TLS 1.3 this was a 0-RTT resumption which allows malicious actors to read all of the past communications using the same PSK. The flaw was detailed by rfc5077 in 2008 and web server default configurations have not widely adopted the changes.'
-VALIDATION_ERROR_SESSION_RESUMPTION_CACHING_TLS1_3 = 'This server has a privacy issue; unrestricted use of session resumption mechanisms and can be shared with third-party trackers. TLS1.3 lifetime of session IDs offers duration up to seven days where afterwards the client attempts a 1-RTT resumption and the server falls back to a full handshake. The server can link both PSKs to the same user, while the user’s resumption lifetime is prolonged with the new PSK and not issued with any new unique identifier. This vulnerability was disclosed by the University of Hamburg in 2018 based on prior works by Dominik Herrmann, Christian Banse, and H. Federrath in 2013'
-VALIDATION_ERROR_SESSION_RESUMPTION_TICKETS = 'A single key is used for the sessions of multiple users and is intended to mitigate privacy concerns of individual tracking, though a ticket identifier can be reused by a malicious actor for multiple or subsequent connections and decrypt all messages as resumed connections don\'t perform any Diffie-Hellman exchange, so they don\'t offer Forward Secrecy against the compromise of the STEK. This vulnerability was first identified by Adam Langley in 2013 which was built on works by M. Perry. in 2012'
+VALIDATION_ERROR_SESSION_RESUMPTION_CACHING = 'Session Resumption (caching) This server has confidentiality vulnerability and a tracking issue affecting privacy; rfc5246 recommends a lifetime of session IDs of less than 24 hours where afterwards the client attempts a resumption and only then the server falls back to a full handshake. The server can link both PSKs to the same user, session resumption caching allows a user identity to be shared with third-party trackers observing traffic on this server. Prior to TLS 1.3 this was a 0-RTT resumption which allows malicious actors to read all of the past communications using the same PSK. The flaw was detailed by rfc5077 in 2008 and web server default configurations have not widely adopted the changes.'
+VALIDATION_ERROR_SESSION_RESUMPTION_CACHING_TLS1_3 = 'Session Resumption (caching) This server has a privacy issue; unrestricted use of session resumption mechanisms and can be shared with third-party trackers. TLS1.3 lifetime of session IDs offers duration up to seven days where afterwards the client attempts a 1-RTT resumption and the server falls back to a full handshake. The server can link both PSKs to the same user, while the user’s resumption lifetime is prolonged with the new PSK and not issued with any new unique identifier. This vulnerability was disclosed by the University of Hamburg in 2018 based on prior works by Dominik Herrmann, Christian Banse, and H. Federrath in 2013'
+VALIDATION_ERROR_SESSION_RESUMPTION_TICKETS = 'Session Resumption (tickets) A single key is used for the sessions of multiple users and is intended to mitigate privacy concerns of individual tracking, though a ticket identifier can be reused by a malicious actor for multiple or subsequent connections and decrypt all messages as resumed connections don\'t perform any Diffie-Hellman exchange, so they don\'t offer Forward Secrecy against the compromise of the STEK. This vulnerability was first identified by Adam Langley in 2013 which was built on works by M. Perry. in 2012'
 VALIDATION_ERROR_CLIENT_RENEGOTIATION = 'This server does not properly associate renegotiation handshakes with an existing connection, which allows manipulator-in-the-middle to insert data into HTTPS sessions by sending an unauthenticated request that is processed by a server in a post-renegotiation context.  The flaw was detailed by rfc5746 in 2010 and web server default configurations have not widely adopted the changes.'
 VALIDATION_ERROR_COMPRESSION_SUPPORT = 'This webserver offers TLS compression so that when a client also supports compression several known exploits exist that allow an attacker to perform session hijacking on an authenticated session. BEAST (2012), CRIME (2012), and BREACH (2013) are the well known attacks however various lesser known attacks exist such as "ssl, gone in 30 seconds" (2013) and other related Information Leakage Vulnerabilities'
 VALIDATION_ERROR_EXPOSED_PRIVATE_KEY = 'Your private key is exposed; Attackers in possession of the private key can impersonate the website, eavesdrop on encrypted traffic they have copied, or digitally sign malware on your behalf and distribute to target systems as you identified as the attacker'
-VALIDATION_ERROR_VERSION_INTERFERENCE_CURRENT = 'Your server is not configured to accept clients that only support the current TLS version {current_version} and these clients browsers configured for privacy (and/or highest security) will be shown am error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
-VALIDATION_ERROR_VERSION_INTERFERENCE_COMMON = 'Your server is not configured to accept clients that only support the common common TLS version {common_version} (You may be limited to older or only the newest versions) and these client browsers not yet configured for the latest TLS version {current_version} will be shown am error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
-VALIDATION_ERROR_VERSION_INTERFERENCE_OLD = 'Your server is not configured to accept clients that only support TLS version {old_version} or older, these clients will be shown am error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
-VALIDATION_ERROR_VERSION_INTERFERENCE_OBSOLETE = 'Your server is not configured to accept clients that only support obsolete TLS versions, these clients will be shown am error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
+VALIDATION_ERROR_VERSION_INTERFERENCE_CURRENT = 'Your server is not configured to accept clients that only support the current TLS version {current_version} and these clients browsers configured for privacy (and/or highest security) will be shown an error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
+VALIDATION_ERROR_VERSION_INTERFERENCE_COMMON = 'Your server is not configured to accept clients that only support the common common TLS version {common_version} (You may be limited to older or only the newest versions) and these client browsers not yet configured for the latest TLS version {current_version} will be shown an error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
+VALIDATION_ERROR_VERSION_INTERFERENCE_OLD = 'Your server is not configured to accept clients that only support TLS version {old_version} or older, these clients will be shown an error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
+VALIDATION_ERROR_VERSION_INTERFERENCE_OBSOLETE = 'Your server is not configured to accept clients that only support obsolete TLS versions, these clients will be shown a error "ERR_SSL_VERSION_INTERFERENCE" and not negotiate a secure connection to your server.'
+VALIDATION_ERROR_MISSING_ROOT_CA_AKI = 'The intermediate Certificate with serial number {serial_number} has no Authority Key Identifier (AKI) which indicates either it was intended to be the Root CA and was not in the Trust Store, or it may have been issued invalid without an AKI, or the server provided a malformed Certificate. Without an AKI a valid Certificate chain can not be formed and there is not verifiable trust anchor. The Server Certificate is considered invalid, fake, or malicious.'
 
 class ValidationError(ValueError):
     def __init__(self, message :str = None, openssl_errno :int = None):
